@@ -139,8 +139,7 @@ equinox_set_widget_parameters (const GtkWidget * widget,
 }
 
 static void
-equinox_style_draw_flat_box (DRAW_ARGS)
-{
+equinox_style_draw_flat_box (DRAW_ARGS) {
 
 	if (DETAIL ("tooltip")) {
 		WidgetParameters params;
@@ -157,80 +156,6 @@ equinox_style_draw_flat_box (DRAW_ARGS)
 
 		equinox_draw_tooltip (cr, colors, &params, x, y, width, height);
 		cairo_destroy (cr);
-	/*} else if (DETAIL ("entry_bg")) {
-    //What is being done here is a sneaky hack to make entry widgets work with large curvatures
-    //As Entry widgets are drawn in two parts, first the background frame and then the smaller
-    //one containing text, the outer frame can be covered by the inner text drawing area when the
-    //curvature is large.  So what I've done here is duplicate the frame drawing code, telling the smaller
-    //area to draw outside it's area, which is clipped and has no effect, except when the curvature is
-    //large filling in the gaps that would be cut out otherwise.  This has the penalty that the entry
-    //is drawn twice thus slower but the benifet outways the cost in my opinion.
-
-		WidgetParameters params;
-		EquinoxStyle *equinox_style;
-		EquinoxColors *colors;
-		cairo_t *cr;
-
-		equinox_sanitize_size (window, &width, &height);
-		equinox_style = EQUINOX_STYLE (style);
-		equinox_set_widget_parameters (widget, style, state_type, &params);
-		colors = &equinox_style->colors;
-		cr = equinox_begin_paint (window, area);
-
-		EntryParameters entry;
-		entry.type = EQX_ENTRY_NORMAL;
-		entry.isComboButton = FALSE;
-		entry.isSpinButton = FALSE;
-		if (equinox_is_toolbar_item (widget))
-			entry.isToolbarItem = TRUE;
-		else
-			entry.isToolbarItem = FALSE;
-
-		params.state_type = GTK_WIDGET_STATE (widget);
-		params.active = (params.state_type == GTK_STATE_ACTIVE);
-		params.prelight = (params.state_type == GTK_STATE_PRELIGHT);
-		params.disabled = (params.state_type == GTK_STATE_INSENSITIVE);
-		//params.curvature = 0;
-
-		if (widget && (EQUINOX_IS_COMBO (widget->parent) ||
-				EQUINOX_IS_COMBO_BOX_ENTRY (widget->parent) ||
-				EQUINOX_IS_SPIN_BUTTON (widget))) {
-
-			width += style->xthickness;
-			if (!params.ltr)
-				x -= style->xthickness;
-
-			if (params.ltr)
-				params.corners = EQX_CORNER_TOPLEFT | EQX_CORNER_BOTTOMLEFT;
-			else
-				params.corners = EQX_CORNER_TOPRIGHT | EQX_CORNER_BOTTOMRIGHT;
-
-			if (EQUINOX_IS_SPIN_BUTTON (widget))
-				entry.type = EQX_ENTRY_SPINBUTTON;
-			else
-				entry.type = EQUINOX_IS_COMBO (widget->parent) ? EQX_ENTRY_COMBO : EQX_ENTRY_COMBO_BOX;
-
-			//entry.isCombo = TRUE;
-		}
-
-        /*** Transparency bug hint ***/
-        /*if (!widget || !g_object_get_data(G_OBJECT (widget), "transparent-bg-hint")) {
-            cairo_rectangle (cr, 0, 0, width, height);
-            if (!params.mnr_gradient.use_rgba) {
-                cairo_set_source_rgb (cr, params.parentbg.r, params.parentbg.g, params.parentbg.b);
-                cairo_fill (cr);
-            } else {
-                cairo_set_operator (cr, CAIRO_OPERATOR_SOURCE);
-                cairo_set_source_rgba (cr, &params.parentbg.r, &params.parentbg.g, &params.parentbg.b, WINDOW_OPACITY);
-                cairo_fill (cr);
-                cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-            }
-        }*/
-
-		/*equinox_draw_entry (cr, colors, &params, &entry, x - style->xthickness, y - style->ythickness, width + style->xthickness*2, height + style->ythickness*2, equinox_style->toolbarstyle);
-
-		cairo_destroy (cr);*/
-
 	} else if (DETAIL ("text")) {
 	} else if (detail && state_type == GTK_STATE_SELECTED && (!strncmp ("cell_even", detail, 9) || !strncmp ("cell_odd", detail, 8))) {
 		WidgetParameters params;
@@ -244,8 +169,8 @@ equinox_style_draw_flat_box (DRAW_ARGS)
 
 		equinox_set_widget_parameters (widget, style, state_type, &params);
 		colors = &equinox_style->colors;
-		cr = equinox_begin_paint (window, area);
 
+		cr = equinox_begin_paint (window, area);
 		equinox_draw_list_selection (cr, colors, &params, x, y, width, height);
 		cairo_destroy (cr);
 	} else if (DETAIL ("expander") || DETAIL ("checkbutton")) {
@@ -264,7 +189,7 @@ equinox_style_draw_flat_box (DRAW_ARGS)
 
 		cairo_translate (cr, x, y);
 
-		// Focus avec couleur legerement plus claire que le parentbg
+		// Focus colour lighter than parentbg
 		EquinoxRGB focus_color;
 		equinox_shade (&params.parentbg, &focus_color, equinox_get_lightness(&params.parentbg) < 0.6 ? 1.24 : 1.05);
 		cairo_set_source_rgb (cr, focus_color.r, focus_color.g, focus_color.b);
@@ -272,6 +197,25 @@ equinox_style_draw_flat_box (DRAW_ARGS)
 		cairo_fill (cr);
 
 		cairo_destroy (cr);
+	} else if (detail && (strncmp ("cell_even", detail, 9) || strncmp ("cell_odd", detail, 8)) && widget && EQUINOX_IS_TREE_VIEW(widget)) {
+		WidgetParameters params;
+		EquinoxStyle *equinox_style;
+		EquinoxColors *colors;
+		cairo_t *cr;
+
+		CHECK_ARGS
+		SANITIZE_SIZE
+		equinox_style = EQUINOX_STYLE (style);
+		if (equinox_style->listviewitemstyle == 1 && GTK_IS_TREE_VIEW(widget) && gtk_tree_view_get_rules_hint(GTK_TREE_VIEW(widget))) {
+			equinox_set_widget_parameters (widget, style, state_type, &params);
+			colors = &equinox_style->colors;
+
+			cr = equinox_begin_paint (window, area);
+			equinox_draw_list_item (cr, colors, &params, x, y, width, height, equinox_style->listviewitemstyle);
+			cairo_destroy (cr);
+		} else  {
+			equinox_parent_class->draw_flat_box (style, window, state_type,	shadow_type, area, widget, detail, x, y, width, height);
+		}
 	} else {
 		equinox_parent_class->draw_flat_box (style, window, state_type,	shadow_type, area, widget, detail, x, y, width, height);
 	}
@@ -372,7 +316,7 @@ static void equinox_style_draw_shadow (DRAW_ARGS) {
 		clearlooks_rounded_rectangle (cr, x + 2.5, y + 2.5, width - 3, height - 3, 3, EQX_CORNER_ALL);
 		cairo_stroke (cr);
 	} else if (DETAIL ("pager") || DETAIL ("pager-frame")) {
-    	EquinoxRGB border;
+    EquinoxRGB border;
 
 		equinox_mix_color (&colors->shade[7], &colors->bg[GTK_STATE_SELECTED], 0.15, &border);
 		cairo_set_source_rgb (cr, border.r, border.g, border.b);
@@ -574,12 +518,11 @@ static void equinox_style_draw_handle (DRAW_ARGS, GtkOrientation orientation) {
 		}
 
 		equinox_draw_handle (cr, colors, &params, &handle, x, y, width, height);
-  	}
+  }
 	cairo_destroy (cr);
 }
 
 static void equinox_style_draw_box (DRAW_ARGS) {
-
 	EquinoxStyle *equinox_style = EQUINOX_STYLE (style);
 	EquinoxColors *colors = &equinox_style->colors;
 
@@ -591,7 +534,7 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 	if (DETAIL ("menubar") && !equinox_is_panel_widget_item(widget)) {
 		WidgetParameters params;
 		equinox_set_widget_parameters (widget, style, state_type, &params);
-		equinox_draw_menubar (cr, colors, &params, x, y, width, height, equinox_style->menubarstyle);
+		equinox_draw_menubar (cr, colors, &params, x, y, width, height, equinox_style->menubarstyle, equinox_style->menubarborders);
 	} else if (DETAIL ("button") && widget && widget->parent && (EQUINOX_IS_TREE_VIEW(widget->parent) || EQUINOX_IS_CLIST (widget->parent)  || equinox_object_is_a (G_OBJECT (widget->parent), "ETree") || /* ECanvas inside ETree */ equinox_object_is_a (G_OBJECT (widget->parent), "ETable") /* ECanvas inside ETable */ )) {
 		WidgetParameters params;
 		ListViewHeaderParameters header;
@@ -642,7 +585,7 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 		equinox_set_widget_parameters (widget, style, state_type, &params);
 
 #ifdef HAVE_ANIMATION
-		if (equinox_style->animation && !(widget->parent && widget->parent->parent && EQUINOX_IS_PANEL_WIDGET(widget->parent->parent))) {
+		if (equinox_style->animation && !(widget && widget->parent && widget->parent->parent && EQUINOX_IS_PANEL_WIDGET(widget->parent->parent))) {
 			equinox_animation_connect_button (widget);
 			params.prev_state_type = equinox_animation_starting_state (widget);
 		}
@@ -702,8 +645,8 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 			entry.isToolbarItem = TRUE;
 			equinox_draw_entry (cr, &equinox_style->colors, &params, &entry, x, y, width, height, equinox_style->toolbarstyle);
 		} else {
-	  		equinox_draw_button (cr, &equinox_style->colors, &params, x, y, width, height, equinox_style->buttonstyle);
-	  	}
+	  	equinox_draw_button (cr, &equinox_style->colors, &params, x, y, width, height, equinox_style->buttonstyle);
+	  }
 	} else if (DETAIL ("spinbutton_up") || DETAIL ("spinbutton_down")) {
 
 		WidgetParameters params;
@@ -778,7 +721,7 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 		progressbar.orientation = gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget));
 
     	equinox_draw_progressbar_trough (cr, colors, &params, &progressbar, x, y, width, height, equinox_style->progressbarstyle);
-	} else if (DETAIL ("trough") && widget && (EQUINOX_IS_VSCROLLBAR (widget) || EQUINOX_IS_HSCROLLBAR (widget))) {
+	} else if ((DETAIL ("trough") && widget && (EQUINOX_IS_VSCROLLBAR (widget) || EQUINOX_IS_HSCROLLBAR (widget))) || DETAIL ("stepper")) {
 		WidgetParameters params;
 		ScrollBarParameters scrollbar;
 
@@ -789,7 +732,7 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 		//scrollbar.steppers = equinox_scrollbar_visible_steppers (widget);
 		if (EQUINOX_IS_RANGE (widget))
 			scrollbar.horizontal = GTK_RANGE (widget)->orientation == GTK_ORIENTATION_HORIZONTAL;
-		equinox_draw_scrollbar_trough (cr, colors, &params, &scrollbar, x, y, width, height, equinox_style->scrollbarstyle);
+		equinox_draw_scrollbar_trough (cr, colors, &params, &scrollbar, x, y, width, height, equinox_style->scrollbarstyle, equinox_style->scrollbartrough);
 	} else if (DETAIL ("bar")) {
 		WidgetParameters params;
 		ProgressBarParameters progressbar;
@@ -845,7 +788,7 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 			params.corners = EQX_CORNER_TOPRIGHT | EQX_CORNER_TOPLEFT;
 			params.curvature = (params.curvature > height*0.2) ? height*0.2 : params.curvature;
 			height++;			//hide bottom border so we don't get a double border with menu
-			equinox_draw_menubar_item (cr, colors, &params, x, y, width, height, EQUINOX_IS_PANEL_WIDGET(widget->parent->parent));
+			equinox_draw_menubar_item (cr, colors, &params, x, y, width, height, equinox_style->menubaritemstyle, EQUINOX_IS_PANEL_WIDGET(widget->parent->parent));
 		}
 		else {
 			params.corners = EQX_CORNER_ALL;
@@ -877,7 +820,7 @@ static void equinox_style_draw_box (DRAW_ARGS) {
 				params.corners = EQX_CORNER_ALL;
 			else
 				params.corners = EQX_CORNER_NONE;
-			equinox_draw_scrollbar_slider (cr, colors, &params, &scrollbar, x, y, width, height, equinox_style->scrollbarstyle);
+			equinox_draw_scrollbar_slider (cr, colors, &params, &scrollbar, x, y, width, height, equinox_style->scrollbarstyle, equinox_style->scrollbarmargin);
 		}
 	} else if (DETAIL ("toolbar") || DETAIL ("handlebox_bin") || DETAIL ("dockitem_bin")) {
 		// Only draw the shadows on horizontal toolbars
@@ -1037,7 +980,11 @@ static void equinox_style_draw_vline (GtkStyle * style,
 	SeparatorParameters separator;
 	WidgetParameters params;
 	separator.horizontal = FALSE;
-	separator.inToolbar = EQUINOX_IS_TOOLBAR (widget->parent);
+	if (widget && widget->parent) {
+		separator.inToolbar = EQUINOX_IS_TOOLBAR (widget->parent);
+	} else {
+		separator.inToolbar = FALSE;
+	}
 	equinox_set_widget_parameters (widget, style, state_type, &params);
 
 
@@ -1047,7 +994,7 @@ static void equinox_style_draw_vline (GtkStyle * style,
       EQUINOX_IS_COMBO_BOX (widget->parent->parent->parent)) {
 	}
 	else
-		equinox_draw_separator (cr, colors, &params, &separator, x, y1, 2, y2 - y1, equinox_style->separatorstyle);
+		//equinox_draw_separator (cr, colors, &params, &separator, x, y1, 2, y2 - y1, equinox_style->separatorstyle);
 
 	cairo_destroy (cr);
 }
@@ -1133,7 +1080,7 @@ static void equinox_style_draw_resize_grip (GtkStyle * style,
 	/*if (edge != GDK_WINDOW_EDGE_SOUTH_EAST)
 		return;			// sorry... need to work on this :P*/
 
-	equinox_draw_resize_grip (cr, colors, &params, &grip, x+2*params.xthickness, y+2*params.ythickness, width, height);
+	equinox_draw_resize_grip (cr, colors, &params, &grip, x+2*params.xthickness, y+2*params.ythickness, width, height, equinox_style->resizegripstyle);
 
 	cairo_destroy (cr);
 }
@@ -1180,7 +1127,7 @@ static void equinox_style_draw_arrow (GtkStyle * style,
 
 	if (DETAIL ("arrow")) {
 		arrow.type = EQX_ARROW_COMBO;
-	} else if (DETAIL ("hscrollbar") || DETAIL ("vscrollbar")) {
+	} else if ((DETAIL ("hscrollbar") || DETAIL ("vscrollbar"))) {
 		arrow.type = EQX_ARROW_SCROLL;
 		if (DETAIL ("vscrollbar")) {
 			x++;
@@ -1206,16 +1153,28 @@ static void equinox_style_init_from_rc (GtkStyle * style, GtkRcStyle * rc_style)
 
 	equinox_style->curvature = EQUINOX_RC_STYLE (rc_style)->curvature;
 	equinox_style->menubarstyle = EQUINOX_RC_STYLE (rc_style)->menubarstyle;
+	equinox_style->menubarborders = EQUINOX_RC_STYLE (rc_style)->menubarborders;
+	equinox_style->menubaritemstyle = EQUINOX_RC_STYLE (rc_style)->menubaritemstyle;
 	equinox_style->toolbarstyle = EQUINOX_RC_STYLE (rc_style)->toolbarstyle;
 	equinox_style->buttonstyle = EQUINOX_RC_STYLE (rc_style)->buttonstyle;
 	equinox_style->menuitemstyle = EQUINOX_RC_STYLE (rc_style)->menuitemstyle;
 	equinox_style->listviewheaderstyle = EQUINOX_RC_STYLE (rc_style)->listviewheaderstyle;
+	equinox_style->listviewitemstyle = EQUINOX_RC_STYLE (rc_style)->listviewitemstyle;
 	equinox_style->scrollbarstyle = EQUINOX_RC_STYLE (rc_style)->scrollbarstyle;
+	equinox_style->scrollbartrough = EQUINOX_RC_STYLE (rc_style)->scrollbartrough;
+	equinox_style->scrollbarmargin = EQUINOX_RC_STYLE (rc_style)->scrollbarmargin;
+	equinox_style->scrollbarpadding[0] = EQUINOX_RC_STYLE (rc_style)->scrollbarpadding[0];
+	equinox_style->scrollbarpadding[1] = EQUINOX_RC_STYLE (rc_style)->scrollbarpadding[1];
+	equinox_style->scrollbarpadding[2] = EQUINOX_RC_STYLE (rc_style)->scrollbarpadding[2];
+	equinox_style->scrollbarpadding[3] = EQUINOX_RC_STYLE (rc_style)->scrollbarpadding[3];
 	equinox_style->scrollbar_color = EQUINOX_RC_STYLE (rc_style)->scrollbar_color;
 	equinox_style->scalesliderstyle = EQUINOX_RC_STYLE (rc_style)->scalesliderstyle;
 	equinox_style->checkradiostyle = EQUINOX_RC_STYLE (rc_style)->checkradiostyle;
 	equinox_style->progressbarstyle = EQUINOX_RC_STYLE (rc_style)->progressbarstyle;
 	equinox_style->separatorstyle = EQUINOX_RC_STYLE (rc_style)->separatorstyle;
+	equinox_style->resizegripstyle = EQUINOX_RC_STYLE (rc_style)->resizegripstyle;
+	equinox_style->textstyle = EQUINOX_RC_STYLE (rc_style)->textstyle;
+	equinox_style->textshade = EQUINOX_RC_STYLE (rc_style)->textshade;
 	equinox_style->animation = EQUINOX_RC_STYLE (rc_style)->animation;
 	equinox_style->arrowsize = EQUINOX_RC_STYLE (rc_style)->arrowsize;
 }
@@ -1255,6 +1214,7 @@ static void equinox_style_realize (GtkStyle * style) {
 		equinox_gdk_color_to_cairo (&style->bg[i], &equinox_style->colors.bg[i]);
 		equinox_gdk_color_to_cairo (&style->base[i], &equinox_style->colors.base[i]);
 		equinox_gdk_color_to_cairo (&style->text[i], &equinox_style->colors.text[i]);
+		equinox_gdk_color_to_cairo (&style->fg[i], &equinox_style->colors.fg[i]);
 	}
 }
 
@@ -1278,74 +1238,34 @@ static void equinox_style_draw_focus (GtkStyle * style, GdkWindow * window,
 
 		WidgetParameters params;
 		equinox_set_widget_parameters (widget, style, state_type, &params);
-
-		cairo_translate (cr, x + 0.5, y + (equinox_get_lightness(&colors->bg[GTK_STATE_NORMAL]) > 0.6 ? 0.5 : -0.5));
-		cairo_set_line_width (cr, 1.0);
-
-		/*if (DETAIL ("checkbutton")) {
-			cairo_translate (cr, 18, equinox_get_lightness(&colors->bg[GTK_STATE_NORMAL]) > 0.6 ? -2 : -1);
-			width -= 24;
-		}*/
-
 		EquinoxRGB focus_color = colors->spot[1];
 
-		//if (DETAIL ("expander") || EQUINOX_IS_TREE_VIEW (widget->parent) || EQUINOX_IS_CLIST (widget->parent)) {
-
-			cairo_pattern_t *pattern = cairo_pattern_create_linear (0, 0, width ,0);
-			cairo_pattern_add_color_stop_rgba (pattern, 0.0, focus_color.r, focus_color.g, focus_color.b, 0.0);
-			cairo_pattern_add_color_stop_rgba (pattern, 0.2, focus_color.r, focus_color.g, focus_color.b, 1.0);
-			cairo_pattern_add_color_stop_rgba (pattern, 0.6, focus_color.r, focus_color.g, focus_color.b, 1.0);
-			cairo_pattern_add_color_stop_rgba (pattern, 1.0, focus_color.r, focus_color.g, focus_color.b, 0.0);
-			cairo_set_source (cr, pattern);
-			cairo_move_to (cr, 0, height);
-			cairo_line_to (cr, width, height);
-			cairo_stroke (cr);
-			cairo_pattern_destroy (pattern);
-
-			pattern = cairo_pattern_create_linear (0, 0, width ,0);
-			cairo_pattern_add_color_stop_rgba (pattern, 0.0, focus_color.r, focus_color.g, focus_color.b, 0.0);
-			cairo_pattern_add_color_stop_rgba (pattern, 0.35, focus_color.r, focus_color.g, focus_color.b, 0.25);
-			cairo_pattern_add_color_stop_rgba (pattern, 0.50, focus_color.r, focus_color.g, focus_color.b, 0.25);
-			cairo_pattern_add_color_stop_rgba (pattern, 1.0, focus_color.r, focus_color.g, focus_color.b, 0.0);
-			cairo_set_source (cr, pattern);
-			cairo_move_to (cr, 0, height - 1);
-			cairo_line_to (cr, width, height - 1);
-			cairo_stroke (cr);
-			if (DETAIL ("expander")) {
-				cairo_move_to (cr, 0, height + 1);
-				cairo_line_to (cr, width, height + 1);
-				cairo_stroke (cr);
-			}
-			cairo_pattern_destroy (pattern);
-
-		/*} else {
-
-			if (DETAIL ("button")) {
-				cairo_translate (cr, -1.5, -1.5);
-				width += 2;
-				height += 2;
-			}
-
-			cairo_set_source_rgba (cr, focus_color.r, focus_color.g, focus_color.b, 0.15);
-			clearlooks_rounded_rectangle (cr, 0.5, 0.5, width - 1, height - 1, params.curvature, EQX_CORNER_ALL);
-			cairo_stroke (cr);
-			cairo_set_source_rgba (cr, focus_color.r, focus_color.g, focus_color.b, 0.9);
-			clearlooks_rounded_rectangle (cr, 1.0, 1.0, width - 2, height - 2, params.curvature, EQX_CORNER_ALL);
-			cairo_stroke (cr);
-		}*/
-	} else if (DETAIL ("checkbutton") || DETAIL ("expander")) {
+		cairo_set_line_width (cr, 1.0);
+		cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.10);
+		clearlooks_rounded_rectangle (cr, x, y, width, height, params.curvature, EQX_CORNER_ALL);
+		cairo_fill (cr);
+		cairo_rectangle (cr, x+0.5, y+0.5, width-1, height - (DETAIL ("button") ? 2 : 1));
+		equinox_set_source_rgba (cr, &colors->spot[1], 0.75);
+		cairo_stroke (cr);
+	} else if ((DETAIL ("checkbutton") || DETAIL ("expander") || (DETAIL ("trough") && widget && GTK_IS_SCALE (widget))) || (detail && g_str_has_prefix (detail, "treeview"))) {
 		WidgetParameters params;
 		equinox_set_widget_parameters (widget, style, state_type, &params);
+		double roundness;
+		if (detail && g_str_has_prefix (detail, "treeview")) {
+			roundness = 0;
+		} else {
+			roundness = params.curvature;
+		}
 
 		cairo_translate (cr, x, y);
 		cairo_set_line_width (cr, 1.0);
 
-		cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.15);
-		clearlooks_rounded_rectangle (cr, 0, 0, width - 1, height - 1, params.curvature, EQX_CORNER_ALL);
+		cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.08);
+		clearlooks_rounded_rectangle (cr, 0, 0, width - 1, height - 1, roundness, EQX_CORNER_ALL);
 		cairo_fill (cr);
 
-		cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.45);
-		clearlooks_rounded_rectangle (cr, 0.5, 0.5, width - 1, height - 1, params.curvature, EQX_CORNER_ALL);
+		cairo_set_source_rgba (cr, colors->spot[1].r, colors->spot[1].g, colors->spot[1].b, 0.6);
+		clearlooks_rounded_rectangle (cr, 0.5, 0.5, width - 1, height - 1, roundness, EQX_CORNER_ALL);
 		cairo_stroke (cr);
 	}
 
@@ -1359,13 +1279,26 @@ static void equinox_style_copy (GtkStyle * style, GtkStyle * src) {
 	eqx_style->colors = eqx_src->colors;
 	eqx_style->curvature = eqx_src->curvature;
 	eqx_style->menubarstyle = eqx_src->menubarstyle;
+	eqx_style->menubarborders = eqx_src->menubarborders;
+	eqx_style->menubaritemstyle = eqx_src->menubaritemstyle;
 	eqx_style->toolbarstyle = eqx_src->toolbarstyle;
 	eqx_style->buttonstyle = eqx_src->buttonstyle;
 	eqx_style->scrollbarstyle = eqx_src->scrollbarstyle;
+	eqx_style->scrollbartrough = eqx_src->scrollbartrough;
+	eqx_style->scrollbarmargin = eqx_src->scrollbarmargin;
+	eqx_style->scrollbarpadding[0] = eqx_src->scrollbarpadding[0];
+	eqx_style->scrollbarpadding[1] = eqx_src->scrollbarpadding[1];
+	eqx_style->scrollbarpadding[2] = eqx_src->scrollbarpadding[2];
+	eqx_style->scrollbarpadding[3] = eqx_src->scrollbarpadding[3];
 	eqx_style->scrollbar_color = eqx_src->scrollbar_color;
 	eqx_style->checkradiostyle = eqx_src->checkradiostyle;
 	eqx_style->listviewheaderstyle = eqx_src->listviewheaderstyle;
+	eqx_style->listviewitemstyle = eqx_src->listviewitemstyle;
 	eqx_style->progressbarstyle = eqx_src->progressbarstyle;
+	eqx_style->separatorstyle = eqx_src->separatorstyle;
+	eqx_style->resizegripstyle = eqx_src->resizegripstyle;
+	eqx_style->textstyle = eqx_src->textstyle;
+	eqx_style->textshade = eqx_src->textshade;
 	eqx_style->arrowsize = eqx_src->arrowsize;
 	eqx_style->animation = eqx_src->animation;
 
@@ -1554,7 +1487,7 @@ equinox_style_init (EquinoxStyle * style)
 
 
 static void equinox_style_draw_layout (GtkStyle * style,
-	     GdkWindow * window,
+		     GdkWindow * window,
 	     GtkStateType state_type,
 	     gboolean use_text,
 	     GdkRectangle * area,
@@ -1570,7 +1503,125 @@ static void equinox_style_draw_layout (GtkStyle * style,
 	if (area)
 		gdk_gc_set_clip_rectangle (gc, area);
 
-	if (state_type == GTK_STATE_INSENSITIVE) {
+	if (widget && (state_type == GTK_STATE_INSENSITIVE ||
+	    (EQUINOX_STYLE (style)->textstyle != 0 &&
+	     state_type != GTK_STATE_PRELIGHT &&
+	     !(DETAIL ("cellrenderertext") && state_type == GTK_STATE_NORMAL))))
+	{
+		EquinoxStyle *equinox_style = EQUINOX_STYLE (style);
+		EquinoxColors *colors = &equinox_style->colors;
+
+		WidgetParameters params;
+
+		equinox_set_widget_parameters (widget, style, state_type, &params);
+
+		GdkColor etched;
+		EquinoxRGB temp;
+
+		double shade_level = equinox_style->textshade;
+		double xos = 0;
+		double yos = 0;
+
+		switch (equinox_style->textstyle) {
+			case 1:
+				yos = +0.5;
+ 				break;
+			case 2:
+				yos = -0.5;
+				break;
+			case 3:
+				xos = 0.5;
+				yos = 0.5;
+				break;
+			case 4:
+				xos = -0.5;
+				yos = -0.5;
+				break;
+		}
+
+		if (state_type == GTK_STATE_INSENSITIVE) {
+			shade_level = 1.24;
+			xos = 0.5;
+			yos = 0.5;
+		}
+
+		if (!gtk_widget_get_has_window (widget)) {
+			boolean use_parentbg = TRUE;
+			while (widget->parent) {
+				if (EQUINOX_IS_BUTTON(widget->parent) ||
+				    EQUINOX_IS_TOGGLE_BUTTON(widget->parent) ||
+				    EQUINOX_IS_COMBO_BOX(widget->parent) ||
+				    EQUINOX_IS_COMBO_BOX_ENTRY(widget->parent) ||
+				    EQUINOX_IS_COMBO(widget->parent) ||
+				    EQUINOX_IS_OPTION_MENU(widget->parent) ||
+				    EQUINOX_IS_NOTEBOOK(widget->parent)) {
+					GtkReliefStyle relief = GTK_RELIEF_NORMAL;
+					// Check for the shadow type.make
+					if (EQUINOX_IS_BUTTON (widget->parent))
+						g_object_get (G_OBJECT (widget->parent), "relief", &relief, NULL);
+
+					if (!EQUINOX_IS_CHECK_BUTTON(widget->parent) &&
+					    !EQUINOX_IS_RADIO_BUTTON(widget->parent) &&
+					    !(relief == GTK_RELIEF_NONE &&
+					      (state_type == GTK_STATE_NORMAL ||
+					       state_type == GTK_STATE_INSENSITIVE)))
+						use_parentbg = FALSE;
+
+					break;
+				}
+				widget = widget->parent;
+			}
+
+			if (use_parentbg)
+				murrine_shade (&params.parentbg, shade_level, &temp);
+			else if (DETAIL ("cellrenderertext"))
+				murrine_shade (&colors->base[state_type], shade_level, &temp);
+			else
+				murrine_shade (&colors->bg[state_type], shade_level, &temp);
+		}
+		else if (DETAIL ("cellrenderertext"))
+			//murrine_shade (&colors->base[state_type], shade_level, &temp);
+			murrine_shade (&colors->base[GTK_STATE_NORMAL], shade_level - 0.12, &temp);
+		else
+			murrine_shade (&colors->bg[state_type], shade_level, &temp);
+
+		etched.red = (int) (temp.r*65535);
+		etched.green = (int) (temp.g*65535);
+		etched.blue = (int) (temp.b*65535);
+
+		// with cairo
+		cairo_t *cr;
+		cr = equinox_begin_paint (window, area);
+		cairo_translate (cr, x+xos, y+yos);
+		pango_cairo_layout_path (cr, layout);
+		equinox_set_source_rgba (cr, &temp, 0.5);
+		cairo_stroke (cr);
+		cairo_destroy (cr);
+	}
+
+	if (DETAIL ("accellabel")) {
+		EquinoxStyle *equinox_style = EQUINOX_STYLE (style);
+		EquinoxColors *colors = &equinox_style->colors;
+
+		WidgetParameters params;
+
+		equinox_set_widget_parameters (widget, style, state_type, &params);
+
+		GdkColor etched;
+		EquinoxRGB temp;
+
+		equinox_mix_color (&colors->fg[state_type], &params.parentbg, state_type != GTK_STATE_PRELIGHT ? 0.4 : 0.2, &temp);
+
+		etched.red = (int) (temp.r*65535);
+		etched.green = (int) (temp.g*65535);
+		etched.blue = (int) (temp.b*65535);
+
+		gdk_draw_layout_with_colors(window, gc, x, y, layout, &etched, NULL);
+	}
+	else
+		gdk_draw_layout (window, gc, x, y, layout);
+
+	/*if (state_type == GTK_STATE_INSENSITIVE) {
 		EquinoxStyle *equinox_style = EQUINOX_STYLE (style);
 		EquinoxColors *colors = &equinox_style->colors;
 
@@ -1599,7 +1650,7 @@ static void equinox_style_draw_layout (GtkStyle * style,
 
     	gdk_draw_layout (window, style->text_gc[state_type], x, y, layout);
 	} else
-		gdk_draw_layout (window, gc, x, y, layout);
+		gdk_draw_layout (window, gc, x, y, layout);*/
 
   	if (area)
     	gdk_gc_set_clip_rectangle (gc, NULL);
